<template>
  <!-- 设备绑定队员 -->
  <el-dialog :before-close="handleClose" :visible.sync="showFormDia" title="绑定组织" top="9vh" width="50%">
    <div class="tree-table-container">
      <el-row class="fullheight">
        <el-col :span="12" class="fullheight" style="height: 65vh;">
          <div class="common-tree-container">
            <div class="common-tree-title">
              <i class="el-icon-menu" /> 组织目录
            </div>
            <div class="common-tree-content">
              <el-tree ref="tree" :check-strictly="true" :data="depts" :props="defaultProps" default-expand-all
                       highlight-current
                       node-key="id"
                       show-checkbox
                       @check="handleCheckChange" />
            </div>
          </div>
        </el-col>
      </el-row>
    </div>
    <span slot="footer" class="dialog-footer">
            <el-button :loading="bindLoading" type="primary" @click="confirmBinding">绑 定</el-button>
            <el-button @click="handleClose">取 消</el-button>
        </span>
  </el-dialog>
</template>
<script>
import TeamMemberManage from '@/api/manager/duty/AssociateGroupsDialog'
import ServiceStrong from '@/views/Manage/duty/api/ServiceStrong'

export default {
  name: 'CmgtDutyWorkarrangeFormDialog',
  components: {},
  data() {
    return {
      teamInfo: null, // 新增，用于存储从父组件传递来的队伍信息
      tableMaxHeight: 300,
      loading: false,
      showFormDia: false,
      hasLoaded: false,// 新增标志位，防止重复加载
      selectedNodes: [], // 存储选中的节点
      selectedKeys: [],   // 存储选中的key
      selectedIds: [],
      defaultProps: {
        value: 'id',
        label: 'name',
        parentId: 'parentId',
        code: 'code',
        children: 'children'
      },
      total: 0,
      queryParam: {
        pageBean: {
          pageSize: 20,
          page: 1
        },
        params: {},
        querys: []
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'IN',
          parentGroup: '',
          property: 'team_id_',
          relation: 'AND',
          value: ''
        }
        // {
        //   group: 'main',
        //   operation: 'EQUAL',
        //   parentGroup: '',
        //   property: 'm.org_id_',
        //   relation: 'AND',
        //   value: ''
        // }
      ],
      StshowFormDias: false,
      posts: [],
      teams: [],
      depts: [],
      currentTreeNode: '',
      deviceList: [], // 执法仪列表
      memberInfo: null,
      equipmentInfo: null,
      tableData: [],
      bindLoading: false
    }
  },
  created() {
    // this.loadOrg()
    this.actionUrl = window.context.portal
    this.getDeviceCode()
  },
  mounted() {
  },
  methods: {
    open(team) {
      this.equipmentInfo = team
      this.loadData(1)
      // 重置状态
      this.hasLoaded = false
      this.showFormDia = true
      // 只有在有 team.id 时才加载组织树
      if (team && team.id) {
        this.loadOrg(team.id)
      } else {
        console.warn('缺少 team.id 参数')
        this.depts = [] // 清空数据或显示提示
      }
    },
    loadOrg(serviceId) {
      // 防止重复加载
      if (this.hasLoaded) return

      this.hasLoaded = true

      ServiceStrong.getAllOrgTree({serviceId}, res => {
        this.depts = res.data
        // 数据加载完成后，设置默认勾选状态
        this.$nextTick(() => {
          this.setDefaultCheckedNodes()
        })
      })
    },
    // 设置默认勾选状态
    setDefaultCheckedNodes() {
      // 确保树组件已加载
      if (!this.$refs.tree) {
        console.warn('树组件未加载')
        return
      }

      // 获取树组件引用   --修改2前
      // const tree = this.$refs.tree
      // if (!tree) return

      // 收集所有isBind=1的节点id
      const checkedIds = []
      const traverse = (nodes) => {
        nodes.forEach(node => {
          if (node.isBind === 1) {
            checkedIds.push(node.id)
          }
          if (node.children && node.children.length) {
            traverse(node.children)
          }
        })
      }

      traverse(this.depts)

      // 设置勾选状态
      // tree.setCheckedKeys(checkedIds)
      // 确保在下一个 tick 执行，等待树完全渲染
      this.$nextTick(() => {
        try {
          // 设置勾选状态
          this.$refs.tree.setCheckedKeys(checkedIds)
          // 更新selectedIds
          this.selectedIds = this.$refs.tree.getCheckedKeys()
          console.log('默认勾选节点设置完成:', checkedIds)
        } catch (error) {
          console.error('设置默认勾选节点失败:', error)
        }
        // tree.setCheckedKeys(checkedIds)  --修改2前
        // 更新selectedIds为完全选中的节点
        // this.selectedIds = tree.getCheckedKeys()   --修改2前
        // 强制更新视图
        // this.$forceUpdate()

        //--以下修改前
        // tree.setCheckedKeys(checkedIds)
        // // 强制更新视图
        // this.$forceUpdate()
      })
      // 同时更新selectedIds
      // this.selectedIds = checkedIds   --修改前
    },

    handleCheckChange(checkedNodes, checkedKeys) {
      console.log('当前选中的节点:', checkedNodes)
      console.log('当前选中的节点keys:', checkedKeys)

      // 存储选中的节点数据
      // this.selectedNodes = checkedNodes
      // 获取当前所有选中的节点ID（包括半选状态）
      // const tree = this.$refs.tree
      // const fullCheckedKeys = tree.getCheckedKeys() // 全选节点
      // const halfCheckedKeys = tree.getHalfCheckedKeys() // 半选节点
      // 合并全选和半选节点（如果需要）
      // this.abc = [...fullCheckedKeys, ...halfCheckedKeys]
      // 提取选中节点的id
      // this.selectedIds = checkedKeys.checkedNodes.map(node => node.id)
      // console.log('选中的组织ID:', this.selectedIds)

      //修改前-以上 -以下为修改

      // 获取完全选中的节点ID（不包括半选状态的父节点）
      const fullyCheckedKeys = this.$refs.tree.getCheckedKeys()
      // 存储完全选中的ID
      this.selectedIds = fullyCheckedKeys
      // 如果需要，可以获取半选状态的父节点ID
      const halfCheckedKeys = this.$refs.tree.getHalfCheckedKeys()

      console.log('完全选中的节点ID:', fullyCheckedKeys)
      console.log('半选状态的节点ID:', halfCheckedKeys)
      console.log('选中的节点数据:', checkedNodes)
    },
    confirmBinding() {
      // if (this.selectedNodes.length === 0) {
      //   this.$message.error('请先选择要绑定的组织！')
      // }
      // 修改前-----  取消验证
      // if (this.selectedIds.length === 0) {
      //   this.$message.error('请先选择要绑定的组织！')
      //   return // 添加return防止继续执行
      // }
      // const orgIds = this.selectedNodes.map(node => node.id).join(',')
      // const id = this.equipmentInfo.id // 从open方法传入的team.id
      this.$confirm('确定要绑定选中的组织吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.bindLoading = true
        // 构造FormData
        const formData = new FormData()
        formData.append('id', this.equipmentInfo.id)
        // 构造查询字符串
        // const queryString = orgIds.map(orgIds => `orgIds=${orgIds}`).join('&')
        // const queryString = 'orgIds=' + this.selectedIds.map(orgIds => orgIds).join('&orgIds=')
        // 构造查询字符串
        const queryString = this.selectedIds.map(id => `orgIds=${id}`).join('&')

        // 调用接口
        ServiceStrong.deviceBindingUnbinding({
          formData: formData,
          queryString: queryString
        }, res => {
          if (res.state) {
            this.$message.success('绑定成功')
            this.handleClose()
            this.$emit('refreshData')
          } else {
            this.$message.error(res.message || '绑定失败')
          }
          this.bindLoading = false
        })
      }).catch(() => {
        this.$message.info('已取消绑定')
      })

    },

    // 获取执法记录仪信息
    getDeviceCode() {
      let obj = {
        groupRelation: 'AND',
        groupTree: {},
        pageBean: {
          page: 1,
          pageSize: -1,
          showTotal: true
        },
        querys: [
          {
            group: 'main',
            operation: 'EQUAL',
            parentGroup: '',
            property: 'p.code_',
            relation: 'AND',
            value: 'ydzfjly'
          }
        ]
      }
      TeamMemberManage.getDeviceInfo(obj, res => {
        console.log(res)
        this.deviceList = res.rows
      })
    },

    // handleNodeClick(data) {
    //   // 点击分类树节点
    //   this.currentTreeNode = data
    //   console.log(data, '888888888888888')
    //   this.loadData(1)
    // },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = null
      this.querys[2].value = null
      this.currentTreeNode = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.currentTreeNode) {
        // if (this.currentTreeNode.dataType === 'ORG') {
        //     this.querys[2].value = this.currentTreeNode.id
        //     this.queryParam.querys.push(this.querys[2])
        // } else {
        //     this.querys[1].value = this.currentTreeNode.id
        //     this.queryParam.querys.push(this.querys[1])
        // }
        this.querys[2].value = this.currentTreeNode.id
        this.queryParam.querys.push(this.querys[2])
      }
      TeamMemberManage.pageQuery(this.queryParam).then(res => {
        const {
          data: {total, rows}
        } = res
        this.total = total
        this.tableData = rows
        this.tableData.forEach(item => {
          this.deviceList.forEach(it => {
            if (item.deviceCode === it.code) {
              item.deviceCodeName = it.name
            }
          })
        })
        this.$set(this.tableData)
        this.loading = false
      })
    },
    handleReset() {
      this.queryParam.params = {}
      this.queryParam.querys = []
      this.clearQuerys && this.clearQuerys()
      this.handleSearch()
    },
    handleSearch() {
      this.queryParam.pageBean.page = 1
      this.loadData()
    },
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.loadData(1)
    },
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.loadData()
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    teamFormat(row, column, cellValue, index) {
      for (var i = 0; i < this.teams.length; i++) {
        if (cellValue === this.teams[i].id) {
          return this.teams[i].name
        }
      }
    },
    orgFormat(row, column, cellValue, index) {
      for (var i = 0; i < this.teams.length; i++) {
        if (cellValue === this.teams[i].id) {
          return this.teams[i].orgName
        }
      }
    },
    handleClose() {
      this.memberInfo = null
      this.equipmentInfo = null
      this.tableData = []
      this.showFormDia = false
    }
  }
}
</script>
<style lang="scss" scoped>
.common-tree-container {
  box-shadow: none !important;
}

::v-deep.el-dialog__body {
  height: 65vh;
}

::v-deep.bbsl-table-search,
::v-deep.bbsl-table-content {
  box-shadow: none;
}

::v-deep.bbsl-table-content {
  margin-top: 0;
  padding: 0 20px;
  // height: 55vh;
}

.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
